==> cmdline-til-0.3.1.tar.gz: cmdline-til-0.3.1/til/til.py <==
#!/usr/bin/python3

"""
TIL
Take down Today I Learned notes faster.
"""
import datetime
import os
import subprocess
import sys
import json

__version__ = "0.3.1"

BASE_PATH = os.path.dirname(os.path.abspath(__file__))


def keyboard_interrupt(func):
    def new_func(*args, **kwargs):
        try:
            func(*args, **kwargs)
        except KeyboardInterrupt:
            print("Quitting...\n")
            sys.exit(-1)
    return new_func


@keyboard_interrupt
def main():
    """
    Determines what functions to call via the arguments from sys.argv
    """
    args = sys.argv

    folder_flags = ['-f', '-F', '--folder']
    folder_name = None
    # Run through args and check for commands
    for i, command in enumerate(args):
        # Check if there is a folder flag.
        if command in folder_flags:
            folder_name = args[i+1]

    if len(args) <= 1:
        print('\ntil: today i learned {}\n\n'
              '  Usage:\n'
              '  til "<title>" [-f "<subfolder_name>"]\n'
              '  til push [-m "<git commit message>"]\n'
              '  til pull\n'
              '  til publish\n'
              '  til setup\n'.format(__version__))
        return

    if args[1] == 'push':
        # Todo: Add pre push hook
        # Check if there is a git commit message flag
        git_commit_msg_flags = ['-m', '-M', '--message']
        git_commit_msg = None
        for j, command in enumerate(args):
            if command in git_commit_msg_flags:
                git_commit_msg = args[j+1]
            else:
                git_commit_msg = None

        # Execute Git commit
        git_add_commit_push(helper_get_settings().get('notes_dir'), git_commit_msg)

    elif args[1] == 'pull':
        git_pull(helper_get_settings().get('notes_dir'))

    elif args[1] == 'setup':
        setup()

    elif args[1] == 'publish':
        settings = helper_get_settings()
        publish(settings)

    else:
        # Todo: Add pre note hook.
        til_settings = helper_get_settings()
        note_create(args[1], til_settings, folder_name=folder_name)

    return


@keyboard_interrupt
def note_create(title, settings, **kwargs):
    """
    Creates a basic note
    :param args:
    :return: None
    """
    note_name = title.capitalize()
    notes_dir = settings.get('notes_dir')
    editor = settings.get('editor')
    template_dir = settings.get('template_dir')
    template = settings.get('template')

    sub_folder_name = kwargs.get('folder_name', None)

    file_name = helper_generate_file_name(note_name)
    file_path = os.path.join(notes_dir, file_name)

    if sub_folder_name:
        helper_verify_sub_folder(notes_dir, sub_folder_name)
        file_path = os.path.join(notes_dir, sub_folder_name, file_name)

    # Verify notes directory
    helper_verify_directory(notes_dir)

    # Title to add to the top of the note
    note_title = note_name

    # Read template
    with open(os.path.join(template_dir, template)) as template_file:
        template_base = template_file.read()

    template = template_base.format(
        note_title=note_title,
        date=datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
        sub_folder=sub_folder_name
    )

    # Check file path to make sure it doesn't exist
    file_exists = os.path.exists(file_path)
    if file_exists:
        overwrite = input("File exists, overwrite? (y/n): ").lower()
        if overwrite != 'y':
            print("Exiting")
            sys.exit(0)

    helper_create_base_file(file_path, template=template)
    helper_open_editor(editor, file_path)

    print("TIL created: {}".format(file_path))
    return


@keyboard_interrupt
def git_add_commit_push(notes_dir, git_commit_msg):
    # Verify git directory
    git_initialized = helper_verify_git(notes_dir)
    if not git_initialized:
        print("Notes folder has not been git initialized.")
        sys.exit(0)

    if git_commit_msg:
        msg = "-m '{}'".format(git_commit_msg)
    else:
        msg = '"Commit dated {}"'.format(datetime.datetime.now().strftime('%Y-%m-%d-%H_%M'))

    add_pr = subprocess.Popen(
        "/usr/bin/git add -A",
        cwd=notes_dir,
        shell=True,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
        universal_newlines=True
        )
    (out, error) = add_pr.communicate()
    print(out)
    if error:
        print("Error occurred while adding changes: \n{}".format(error))
        sys.exit(-1)

    # Commit Changes
    commit_pr = subprocess.Popen(
        "/usr/bin/git commit -m '{}'".format(msg),
        cwd=notes_dir,
        shell=True,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
        universal_newlines=True
        )
    (out, error) = commit_pr.communicate()
    print(out)
    if error:
        print("Error occurred while committing changes: \n{}".format(error))
        sys.exit(-1)

    # Push Changes to origin from master branch
    push_pr = subprocess.Popen(
        "/usr/bin/git push origin master".format(msg),
        cwd=notes_dir,
        shell=True,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
        universal_newlines=True
        )
    (out, error) = push_pr.communicate()
    print(out or error)
    sys.exit(-1)


@keyboard_interrupt
def git_pull(notes_dir):
    # Verify git directory
    git_initialized = helper_verify_git(notes_dir)
    if not git_initialized:
        print("Notes folder has not been git initialized.")
        sys.exit(-1)

    add_pr = subprocess.Popen(
            "/usr/bin/git pull",
            cwd=notes_dir,
            shell=True,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            universal_newlines=True
            )
    (out, error) = add_pr.communicate()
    print(out)
    if error:
        print("Error occurred while adding changes: \n{}".format(error))
        sys.exit(-1)


def publish(settings):
    """
    Convert notes in notes dir to jekyll style posts in jekyll posts directory
    :param settings:
    :return:
    """
    # Grab Jekyll _posts folder location
    notes_folder = settings.get('notes_dir', None)
    posts_folder = settings.get("jekyll_posts_folder", None)

    if not posts_folder:
        print("Jekyll posts folder not found, please run til setup.")
        sys.exit(-1)

    print("Publishing to Jekyll posts folder at {}".format(posts_folder))

    # Convert note names to jekyll style names
    for file in os.listdir(notes_folder):
        # Skip files/folders
        restricted_files = ['jekyll', 'templates', '.git', '.gitignore']
        if file in restricted_files:
            continue

        if os.path.isdir(os.path.join(notes_folder, file)):
            sub_directory = os.listdir(os.path.join(notes_folder, file))
            for sub_file in sub_directory:
                helper_convert_to_jekyll(os.path.join(notes_folder, file, sub_file), posts_folder)
        elif not os.path.isdir(file):
            helper_convert_to_jekyll(os.path.join(notes_folder, file), posts_folder)

    print("Publishing complete.")


@keyboard_interrupt
def setup():
    # Setup home directory
    notes_dir = os.path.join(os.path.expanduser("~"), "til")
    alt_dir = input("Where do you want to save your notes? (default: {}): ".format(notes_dir))

    if alt_dir:
        notes_dir = alt_dir
    dir_exists = helper_verify_directory(notes_dir)

    if not dir_exists:
        create_dir = input("{} does not exist, create it? (y/n): ".format(notes_dir)).lower()
    else:
        create_dir = None

    if create_dir == 'y':
        try:
            os.makedirs(notes_dir)
        except PermissionError:
            print(notes_dir)
            print("Permission Denied.  Could not create folder")
            sys.exit(-1)

    # Setup text editor
    editor = ["vim", "+normal Go", "+startinsert"]
    alt_editor = input("What is the path to the executable for the editor you want to use? (default: {}): ".format(
        " ".join(editor)))
    if alt_editor:
        editor = alt_editor
    else:
        editor = editor

    # Save base template to cmdline-til folder
    template_dir = os.path.join(notes_dir, 'templates')
    try:
        os.makedirs(template_dir)
    except FileExistsError:
        pass

    base_template = [
        '#title:  {note_title}\n',
        '##date:  {date}\n',
        '##sub-folder:  {sub_folder}\n',
    ]
    with open(os.path.join(template_dir, 'base_template.md'), "w+") as f:
        f.writelines(base_template)

    posts_folder = input("If using jekyll, what is location of the _posts folder? (Enter to skip): ")

    settings_json = {
        "notes_dir": notes_dir,
        "editor": editor,
        "template_dir": template_dir,
        "template": 'base_template.md',
        "jekyll_posts_folder": posts_folder
    }

    # Save settings to file in home folder
    settings_file = os.path.join(os.path.expanduser("~"), ".til")
    with open(settings_file, "w+") as f:
        f.write(json.dumps(settings_json))

    print("Settings saved to {}".format(settings_file))
    return settings_json


def helper_get_settings():
    try:
        with open(os.path.join(os.path.expanduser("~"), ".til")) as f:
            til_settings = json.loads(f.read())
            return til_settings
    except FileNotFoundError:
        print("Settings file not found.  Please run til setup.")
        sys.exit(-1)


def helper_open_editor(editor_command, file_path):
    """
    Helper function that opens text editor.
    :param editor_command:
    :param file_path:
    :param peek:
    :return: None
    """
    editor_command.append(file_path)
    subprocess.call(editor_command)
    return


def helper_generate_file_name(note_name):
    """
    Helper function to generate file name based on note title and date.
    :param note_name:
    :return: str
    """
    note_name = "-".join(note_name.split(" "))
    note_full_name = "{note_name}.md".format(note_name=note_name)
    return note_full_name


def helper_create_base_file(file_path, template=None):
    """
    Helper function to create note file and populate it with templated information
    :param file_path:
    :param template:
    :return: None
    """
    with open(file_path, 'w') as f:
        if template:
            f.writelines(template)
        else:
            # Create empty file.
            pass
    return


def helper_space_print(string):
    """Helper function to add new lines around print output."""
    print("\n" + string + "\n")


def helper_verify_directory(path):
    """Helper function that makes sure the notes directory exists."""
    exists = os.path.isdir(path)
    if not exists:
        return False
    else:
        return True


@keyboard_interrupt
def helper_verify_sub_folder(notes_dir, folder_name):
    """Helper function that makes sure the notes directory exists."""
    folders = os.listdir(notes_dir)

    # Pull list of folders in notes dir
    folder_list = []
    for item in folders:
        is_folder = os.path.isdir(os.path.join(notes_dir, item))
        if is_folder:
            folder_list.append(item)

    # Check for new directory in notes folder
    new_folder_path = os.path.join(notes_dir, folder_name)
    if folder_name in folder_list:
        return True

    # Create the directory if it doesn't exist
    create_dir = input("{} does not exist, create it? (y/n): ".format(new_folder_path)).lower()
    if create_dir == 'y':
        try:
            os.makedirs(new_folder_path)
            return True
        except PermissionError:
            print("Could not create {}, permission denied.".format(
                new_folder_path))
            sys.exit(-1)
    else:
        print("Folder not created, exiting.")
        sys.exit(-1)


def helper_verify_git(notes_dir):
    try:
        if ".git" in os.listdir(notes_dir):
            dir_check = os.path.isdir(os.path.join(notes_dir, '.git'))
            if dir_check:
                return True
            else:
                return False
        else:
            return False
    except FileNotFoundError:
        print("{} not found.".format(notes_dir))
        sys.exit(-1)


def helper_convert_to_jekyll(input_file_path, output_folder_path):
    """
    Helps convert a note to a jekyll post.
    :param input_file_path:
    :param output_file_path:
    :return:
    """
    print("Converting {}".format(input_file_path))
    with open(input_file_path) as f:
        lines = f.readlines()

    title = ''
    note_date = datetime.datetime.now()
    sub_folder = ''
    for i, line in enumerate(lines):
        if 'title:' in line:
            title = line.replace("#","").replace("title:", "").lstrip().rstrip()
            del(lines[i])
        elif 'date:' in line:
            date_string = line.replace("#","").replace("date:", "").lstrip().rstrip()
            note_date = datetime.datetime.strptime(date_string, '%Y-%m-%d %H:%M:%S')
            del(lines[i])
        elif 'sub-folder: ' in line:
            sub_folder = line.replace("#","").replace("sub-folder:", "").lstrip().rstrip()
            del(lines[i])


    jekyll_front_matter = [
        "---\n",
        "layout: post\n",
        "title: {}\n".format(title),
        "date: {}\n".format(note_date.strftime('%Y-%m-%d %H:%M:%S')),
        "category: {}\n".format(sub_folder),
        "---\n"
    ]

    output_file_name = "{date}-{title}.md".format(
        date=note_date.strftime("%Y-%m-%d"),
        title=title.replace(" ", "-").lower()
    )

    output_file_path = os.path.join(output_folder_path, output_file_name)

    with open(output_file_path, "w+") as f:
        f.writelines(jekyll_front_matter)
        f.writelines(lines)



if __name__ == '__main__':
    main()

==> cmdline-til-0.4.3.tar.gz: cmdline-til-0.4.3/til/til.py <==
#!/usr/bin/python3

"""
TIL
Take down Today I Learned notes faster.
"""
import datetime
import os
import subprocess
import sys
import json
from til import editors


__version__ = "0.4.3"

BASE_PATH = os.path.dirname(os.path.abspath(__file__))


def keyboard_interrupt(func):
    def new_func(*args, **kwargs):
        try:
            func(*args, **kwargs)
        except KeyboardInterrupt:
            print("Quitting...\n")
            sys.exit(-1)
    return new_func


@keyboard_interrupt
def main():
    """
    Determines what functions to call via the arguments from sys.argv
    """
    args = sys.argv

    folder_flags = ['-f', '-F', '--folder']
    folder_name = None
    # Run through args and check for commands
    for i, command in enumerate(args):
        # Check if there is a folder flag.
        if command in folder_flags:
            folder_name = args[i+1]

    if len(args) <= 1:
        print('\ntil: today i learned {}\n\n'
              '  Usage:\n'
              '  til "<title>" [-f "<subfolder_name>"]\n'
              '  til push [-m "<git commit message>"]\n'
              '  til pull\n'
              '  til publish\n'
              '  til setup\n'.format(__version__))
        return

    if args[1] == 'push':
        # Todo: Add pre push hook
        # Check if there is a git commit message flag
        git_commit_msg_flags = ['-m', '-M', '--message']
        git_commit_msg = None
        for j, command in enumerate(args):
            if command in git_commit_msg_flags:
                git_commit_msg = args[j+1]
            else:
                git_commit_msg = None

        # Execute Git commit
        git_add_commit_push(helper_get_settings(), git_commit_msg)

    elif args[1] == 'pull':
        git_pull(helper_get_settings())

    elif args[1] == 'setup':
        setup()

    elif args[1] == 'publish':
        settings = helper_get_settings()
        publish(settings)

    else:
        # Todo: Add pre note hook.
        til_settings = helper_get_settings()
        note_create(args[1], til_settings, folder_name=folder_name)

    return


@keyboard_interrupt
def note_create(title, settings, **kwargs):
    """
    Creates a basic note
    :param args:
    :return: None
    """
    # Run pre_create_hook
    helper_run_hook(settings, "pre_create_hook")

    note_name = title.capitalize()
    notes_dir = settings.get('notes_dir')
    editor = settings.get('editor')
    template_dir = settings.get('template_dir')
    template = settings.get('template')

    sub_folder_name = kwargs.get('folder_name', None)

    file_name = helper_generate_file_name(note_name)
    file_path = os.path.join(notes_dir, file_name)

    if sub_folder_name:
        helper_verify_sub_folder(notes_dir, sub_folder_name)
        file_path = os.path.join(notes_dir, sub_folder_name, file_name)

    # Verify notes directory
    helper_verify_directory(notes_dir)

    # Title to add to the top of the note
    note_title = note_name

    # Read template
    with open(os.path.join(template_dir, template)) as template_file:
        template_base = template_file.read()

    template = template_base.format(
        note_title=note_title,
        date=datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
        sub_folder=sub_folder_name
    )

    # Check file path to make sure it doesn't exist
    file_exists = os.path.exists(file_path)
    if file_exists:
        overwrite = input("File exists, overwrite? (y/n): ").lower()
        if overwrite != 'y':
            print("Exiting")
            sys.exit(0)

    helper_create_base_file(file_path, template=template)
    helper_open_editor(editor, file_path)

    print("TIL created: {}".format(file_path))
    helper_run_hook(settings, "post_create_hook")
    return


@keyboard_interrupt
def git_add_commit_push(settings, git_commit_msg):
    # Run pre push hook
    helper_run_hook(settings, 'pre_push_hook')

    notes_dir = settings.get('notes_dir')
    # Verify git directory
    git_initialized = helper_verify_git(notes_dir)
    if not git_initialized:
        print("Notes folder has not been git initialized.")
        sys.exit(0)

    if git_commit_msg:
        msg = "-m '{}'".format(git_commit_msg)
    else:
        msg = '"Commit dated {}"'.format(datetime.datetime.now().strftime('%Y-%m-%d-%H_%M'))

    add_pr = subprocess.Popen(
        "/usr/bin/git add -A",
        cwd=notes_dir,
        shell=True,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
        universal_newlines=True
        )
    (out, error) = add_pr.communicate()
    print(out)
    if error:
        print("Error occurred while adding changes: \n{}".format(error))
        sys.exit(-1)

    # Commit Changes
    commit_pr = subprocess.Popen(
        "/usr/bin/git commit -m '{}'".format(msg),
        cwd=notes_dir,
        shell=True,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
        universal_newlines=True
        )
    (out, error) = commit_pr.communicate()
    print(out)
    if error:
        print("Error occurred while committing changes: \n{}".format(error))
        sys.exit(-1)

    # Push Changes to origin from master branch
    push_pr = subprocess.Popen(
        "/usr/bin/git push origin master".format(msg),
        cwd=notes_dir,
        shell=True,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
        universal_newlines=True
        )
    (out, error) = push_pr.communicate()
    print(out or error)

    helper_run_hook(settings, 'post_push_hook')

    sys.exit(-1)


@keyboard_interrupt
def git_pull(settings):
    helper_run_hook(settings, "pre_pull_hook")

    notes_dir = settings.get('notes_dir')
    # Verify git directory
    git_initialized = helper_verify_git(notes_dir)
    if not git_initialized:
        print("Notes folder has not been git initialized.")
        sys.exit(-1)

    add_pr = subprocess.Popen(
            "/usr/bin/git pull",
            cwd=notes_dir,
            shell=True,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            universal_newlines=True
            )
    (out, error) = add_pr.communicate()
    print(out)
    if error:
        print("Error occurred while adding changes: \n{}".format(error))
        sys.exit(-1)
    helper_run_hook(settings, "post_pull_hook")


@keyboard_interrupt
def publish(settings):
    """
    Convert notes in notes dir to jekyll style posts in jekyll posts directory
    :param settings:
    :return:
    """
    helper_run_hook(settings, "pre_publish_hook")

    # Grab Jekyll _posts folder location
    notes_folder = settings.get('notes_dir', None)
    posts_folder = settings.get("jekyll_posts_folder", None)

    if not helper_verify_directory(posts_folder):
        print("Jekyll posts folder not found, please run til setup.")
        sys.exit(-1)

    print("Publishing to Jekyll posts folder at {}".format(posts_folder))

    # Convert note names to jekyll style names
    for file in os.listdir(notes_folder):
        tags = []
        # Skip files/folders
        restricted_files = settings.get('jekyll_restricted_files')
        if file in restricted_files:
            continue

        if os.path.isdir(os.path.join(notes_folder, file)):

            # If the file is a directory, traverse it.
            tags.append(file)
            sub_directory = os.listdir(os.path.join(notes_folder, file))
            for sub_file in sub_directory:
                if file in restricted_files:
                    continue
                else:
                    helper_convert_to_jekyll(os.path.join(notes_folder, file, sub_file), posts_folder, tags=tags)

        elif not os.path.isdir(file):
            # If the file is not a directory, convert it.
            helper_convert_to_jekyll(os.path.join(notes_folder, file), posts_folder)

        else:
            continue

    helper_run_hook(settings, "post_publish_hook")
    print("Publishing complete.")



@keyboard_interrupt
def setup():
    settings_file = os.path.join(os.path.expanduser("~"), ".til")
    print("\nWelcome to cmdline-til setup (version {})".format(__version__))
    print("To set up cmdline-til please answer the following questions.\nRun til setup at any time to change default settings.")
    print("All settings will be saved to {}".format(settings_file))

    # Setup home directory
    notes_dir = os.path.join(os.path.expanduser("~"), "til")
    alt_dir = input("\nWhere do you want to save your notes? (default: {}): ".format(notes_dir))

    if alt_dir:
        notes_dir = alt_dir
    dir_exists = helper_verify_directory(notes_dir)

    if not dir_exists:
        create_dir = input("{} does not exist, create it? (y/n): ".format(notes_dir)).lower()
    else:
        create_dir = None

    if create_dir == 'y':
        try:
            os.makedirs(notes_dir)
        except PermissionError:
            print(notes_dir)
            print("Permission Denied.  Could not create folder")
            sys.exit(-1)

    # Setup text editor
    editor = ["vim", "+normal Go", "+startinsert"]
    print("\nWhat is the path to the executable or command for the editor you want to use?")
    print("Examples:")
    print("vim:\t{} (DEFAULT)".format(" ".join(editor)))
    for editor_option in editors.editors:
        print("{}:\t{}".format(editor_option, " ".join(editors.editors[editor_option])))
    alt_editor = input("\nPath or command to editor (Hit enter for default): ")
    if alt_editor:
        editor = alt_editor
    else:
        editor = editor

    # Save base template to cmdline-til folder
    template_dir = os.path.join(notes_dir, 'templates')
    try:
        os.makedirs(template_dir)
    except FileExistsError:
        pass

    base_template = [
        '#title:  {note_title}\n',
        '##date:  {date}\n',
    ]
    with open(os.path.join(template_dir, 'base_template.md'), "w+") as f:
        f.writelines(base_template)

    posts_folder = input("\nIf using jekyll, what is location of the _posts folder? (Enter to skip): ")

    hooks_json = {
        "pre_create_hook": [],
        "post_create_hook": [],
        "pre_push_hook": [],
        "post_push_hook": [],
        "pre_pull_hook": [],
        "post_pull_hook": [],
        "pre_publish_hook": [],
        "post_publish_hook": [],
    }

    settings_json = {
        "notes_dir": notes_dir,
        "editor": editor,
        "template_dir": template_dir,
        "template": 'base_template.md',
        "jekyll_posts_folder": posts_folder,
        "jekyll_restricted_files": ['jekyll', 'templates', '.git', '.gitignore', 'readme.md'],
        "hooks": hooks_json
    }
    # Save settings to file in home folder

    with open(settings_file, "w+") as f:
        f.write(json.dumps(settings_json, indent=4))

    print("Settings saved to {}".format(settings_file))
    return settings_json


def helper_run_hook(settings, hook_name):
    print("Running hook {}".format(hook_name))
    hooks = settings.get('hooks', None)
    if hooks:
        selected_hooks = hooks.get(hook_name, None)
        if selected_hooks:
            for hook in selected_hooks:
                print(hook)
                # Execute each hook command.
                add_pr = subprocess.Popen(
                    hook,
                    shell=True,
                    stdout=subprocess.PIPE,
                    stderr=subprocess.PIPE,
                    universal_newlines=True
                    )
                (out, error) = add_pr.communicate()
                print(out)
                if error:
                    print("Error occurred while executing hook: \n{}".format(error))
                    sys.exit(-1)
    return


def helper_get_settings():
    try:
        with open(os.path.join(os.path.expanduser("~"), ".til")) as f:
            til_settings = json.loads(f.read())
            return til_settings
    except FileNotFoundError:
        print("Settings file not found.  Please run til setup.")
        sys.exit(-1)


def helper_open_editor(editor_command, file_path):
    """
    Helper function that opens text editor.
    :param editor_command:
    :param file_path:
    :param peek:
    :return: None
    """
    editor_command.append(file_path)
    subprocess.call(editor_command)
    return


def helper_generate_file_name(note_name):
    """
    Helper function to generate file name based on note title and date.
    :param note_name:
    :return: str
    """
    note_name = "-".join(note_name.split(" "))
    note_full_name = "{note_name}.md".format(note_name=note_name)
    return note_full_name


def helper_create_base_file(file_path, template=None):
    """
    Helper function to create note file and populate it with templated information
    :param file_path:
    :param template:
    :return: None
    """
    with open(file_path, 'w') as f:
        if template:
            f.writelines(template)
        else:
            # Create empty file.
            pass
    return


def helper_space_print(string):
    """Helper function to add new lines around print output."""
    print("\n" + string + "\n")


def helper_verify_directory(path):
    """Helper function that makes sure the notes directory exists."""
    exists = os.path.isdir(path)
    if not exists:
        return False
    else:
        return True


@keyboard_interrupt
def helper_verify_sub_folder(notes_dir, folder_name):
    """Helper function that makes sure the notes directory exists."""
    folders = os.listdir(notes_dir)

    # Pull list of folders in notes dir
    folder_list = []
    for item in folders:
        is_folder = os.path.isdir(os.path.join(notes_dir, item))
        if is_folder:
            folder_list.append(item)

    # Check for new directory in notes folder
    new_folder_path = os.path.join(notes_dir, folder_name)
    if folder_name in folder_list:
        return True

    # Create the directory if it doesn't exist
    create_dir = input("{} does not exist, create it? (y/n): ".format(new_folder_path)).lower()
    if create_dir == 'y':
        try:
            os.makedirs(new_folder_path)
            return True
        except PermissionError:
            print("Could not create {}, permission denied.".format(
                new_folder_path))
            sys.exit(-1)
    else:
        print("Folder not created, exiting.")
        sys.exit(-1)


def helper_verify_git(notes_dir):
    try:
        if ".git" in os.listdir(notes_dir):
            dir_check = os.path.isdir(os.path.join(notes_dir, '.git'))
            if dir_check:
                return True
            else:
                return False
        else:
            return False
    except FileNotFoundError:
        print("{} not found.".format(notes_dir))
        sys.exit(-1)


def helper_convert_to_jekyll(input_file_path, output_folder_path, tags=None):
    """
    Helps convert a note to a jekyll post.
    :param input_file_path:
    :param output_file_path:
    :return:
    """
    print("Converting {}".format(input_file_path))
    with open(input_file_path) as f:
        lines = f.readlines()

    # Verify output folder
    if not helper_verify_directory(output_folder_path):
        print("Error: The posts directory is invalid. ({})".format(output_folder_path))
        sys.exit(1)

    title = ''
    note_date = datetime.datetime.now()
    line_remove_queue = []
    for i, line in enumerate(lines):
        if '#title:' in line:
            title = line.replace("#", "").replace("title:", "").lstrip().rstrip()
            line_remove_queue.append(i)
        elif '##date:' in line:
            date_string = line.replace("#", "").replace("date:", "").lstrip().rstrip()
            note_date = datetime.datetime.strptime(date_string, '%Y-%m-%d %H:%M:%S')
            line_remove_queue.append(i)

    # Combine tags
    if tags:
        formatted_tags = ", ".join(tags)
    else:
        formatted_tags = ""

    jekyll_front_matter = [
        "---\n",
        "layout: post\n",
        "title: {}\n".format(title),
        "date: {}\n".format(note_date.strftime('%Y-%m-%d %H:%M:%S')),
        "category: til\n",
        "tags: {}\n".format(formatted_tags),
        "---\n"
    ]

    output_file_name = "{date}-{title}.md".format(
        date=note_date.strftime("%Y-%m-%d"),
        title=title.replace(" ", "-").lower()
    )

    output_file_path = os.path.join(output_folder_path, output_file_name)

    # Combine front matter and file data
    final_file = []
    final_file.extend(jekyll_front_matter)
    for i, line in enumerate(lines):
        if i not in line_remove_queue:
            final_file.append(line)

    # Check if file has already been published.
    if os.path.isfile(output_file_path):
        with open(output_file_path) as old_file:
            old_file_contents = old_file.readlines()
        if old_file_contents == final_file:
            print("File Exists.  Skipping {}".format(output_file_path))

    with open(output_file_path, "w+") as f:
        f.writelines(final_file)



if __name__ == '__main__':
    main()
